@@ -25,7 +25,7 @@ Usage::
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
     ```
 """
-from mypy_boto3_batch.client import BatchClient as Client, BatchClient
+from mypy_boto3_batch.client import BatchClient
 from mypy_boto3_batch.paginator import (
     DescribeComputeEnvironmentsPaginator,
     DescribeJobDefinitionsPaginator,
@@ -33,6 +33,8 @@ from mypy_boto3_batch.paginator import (
     ListJobsPaginator,
 )
 
+Client = BatchClient
+
 
 __all__ = (
     "BatchClient",
